@@ -316,7 +316,7 @@ class solidWallTemperatureCoupledFvPatchScalarField( fixedValueFvPatchScalarFiel
 from Foam.template import getfvPatchFieldConstructorToTableBase_scalar
 class fvPatchFieldConstructorToTable_solidWallTemperatureCoupled( getfvPatchFieldConstructorToTableBase_scalar() ):
     def __init__( self ):
-        aBaseClass = getfvPatchFieldConstructorToTableBase_scalar()
+        aBaseClass = self.__class__.__mro__[ 1 ]
         aBaseClass.__init__( self )
         
         from Foam.OpenFOAM import word 
