@@ -76,15 +76,15 @@ def readSolidTimeControls( runTime ):
 
 
 #-------------------------------------------------------------------------------------------------------
-def solidRegionDiffNo( mesh, runTime, Cprho, kappa ):
+def solidRegionDiffNo( mesh, runTime, Cprho, K ):
     DiNum = 0.0
     meanDiNum = 0.0
 
     #- Take care: can have fluid domains with 0 cells so do not test for
     #  zero internal faces.
-    kapparhoCpbyDelta = mesh.deltaCoeffs() * ref.fvc.interpolate( kappa ) / ref.fvc.interpolate(Cprho)
-    DiNum = kapparhoCpbyDelta.internalField().gMax() * runTime.deltaT().value()
-    meanDiNum = kapparhoCpbyDelta.average().value() * runTime.deltaT().value()
+    KrhoCpbyDelta = mesh.deltaCoeffs() * ref.fvc.interpolate( K ) / ref.fvc.interpolate(Cprho)
+    DiNum = KrhoCpbyDelta.internalField().gMax() * runTime.deltaT().value()
+    meanDiNum = KrhoCpbyDelta.average().value() * runTime.deltaT().value()
     
     ref.ext_Info() << "Region: " << mesh.name() << " Diffusion Number mean: " << meanDiNum << " max: " << DiNum << ref.nl
 
@@ -96,8 +96,8 @@ def solidRegionDiffusionNo( solidRegions, runTime, thermos ):
     DiNum = -ref.GREAT
     
     for index in range( solidRegions.__len__() ):
-        mesh, thermo, rho, cp, kappa, T = setRegionSolidFields( index, solidRegions, thermos )
-        DiNum = max( solidRegionDiffNo( solidRegions[ index ], runTime, rho * cp, kappa ), DiNum )
+        mesh, thermo, rho, cp, K, T = setRegionSolidFields( index, solidRegions, thermos )
+        DiNum = max( solidRegionDiffNo( solidRegions[ index ], runTime, rho * cp, K ), DiNum )
         pass
     
     return DiNum
@@ -111,23 +111,23 @@ def setRegionSolidFields( i, solidRegions, thermos ):
 
     cp = man.volScalarField( thermo.Cp(), man.Deps( thermo ) )
     
-    kappa = man.volScalarField( thermo.K(), man.Deps( thermo ) )
+    K = man.volScalarField( thermo.K(), man.Deps( thermo ) )
     # tmp<volSymmTensorField> tK = thermo.directionalK();
     
     # const volSymmTensorField& K = tK();
     T = man.volScalarField( thermo.T(), man.Deps( thermo ) )
     
-    return mesh, thermo, rho, cp, kappa, T
+    return mesh, thermo, rho, cp, K, T
 
 
 #-------------------------------------------------------------------------------------------------------
-def solveSolid( mesh, thermo, rho, cp, kappa, T, nNonOrthCorr, finalIter ):
+def solveSolid( mesh, thermo, rho, cp, K, T, nNonOrthCorr, finalIter ):
     if finalIter:
         mesh.add( ref.word( "finalIteration" ), True )
         pass
 
     for index in range( nNonOrthCorr + 1 ):
-       TEqn = ref.fvm.ddt( rho * cp, T ) - ref.fvm.laplacian( kappa, T )
+       TEqn = ref.fvm.ddt( rho * cp, T ) - ref.fvm.laplacian( K, T )
        TEqn.relax()
        TEqn.solve( mesh.solver( T.select( finalIter ) ) )
        pass
